==> haskell-skein-1.0.9.4-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-2BIkqFdnNXDMYaihlCTHM
key: skein-1.0.9.4-2BIkqFdnNXDMYaihlCTHM
license: BSD-3-Clause
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
abi: 5e407cb6192e23af8f71367240723317
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-2BIkqFdnNXDMYaihlCTHM
includes:
    skein.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU=6900b771227d4e4da26f3f5981befd1d
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skein-1.0.9.4-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-3XMXoX5jaWuJ2f4tKKLZHH
key: skein-1.0.9.4-3XMXoX5jaWuJ2f4tKKLZHH
license: BSD-3-Clause
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
abi: 091c4f90f901dd227f64fc0e8f184cfa
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-3XMXoX5jaWuJ2f4tKKLZHH
includes:
    skein.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=ce10e49cbca1b74596de9d427ce328a8
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
